AppVersionUpdate class

Constructors

AppVersionUpdate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkForUpdates({String? appleId, String? playStoreId, String? country}) Future<AppVersionResult>
Checks for app update in stores, taking into account the local version.
showAlertUpdate({BuildContext? context, AppVersionResult? appVersionResult, bool? mandatory = false, String? title = 'New version available', TextStyle? titleTextStyle = const TextStyle(fontSize: 24.0, fontWeight: FontWeight.w500, color: Colors.black), String? content = 'Would you like to update your application?', TextStyle? contentTextStyle = const TextStyle(fontSize: 16.0, fontWeight: FontWeight.w400, color: Colors.black), ButtonStyle? cancelButtonStyle = const ButtonStyle(backgroundColor: WidgetStatePropertyAll(Colors.redAccent)), ButtonStyle? updateButtonStyle = const ButtonStyle(backgroundColor: WidgetStatePropertyAll(Colors.green)), String? cancelButtonText = 'UPDATE LATER', String? updateButtonText = 'UPDATE', TextStyle? cancelTextStyle = const TextStyle(color: Colors.white), TextStyle? updateTextStyle = const TextStyle(color: Colors.white), Color? backgroundColor = Colors.white}) → dynamic
Displays an alert dialog for the user to decide whether to enter update now or update later.
showBottomSheetUpdate({BuildContext? context, AppVersionResult? appVersionResult, bool mandatory = false, String title = 'New version avaible', Widget? content}) → dynamic
Opens a bottomsheet, with title, content and update options
showPageUpdate({BuildContext? context, AppVersionResult? appVersionResult, bool mandatory = false, Widget? page}) → dynamic
Used for This widget comstujma be used for updates that have terms to accept or explanations Navigate to another page, just pass your widget that will open as a page